summaryrefslogtreecommitdiff
path: root/src/vm/ceemain.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/vm/ceemain.cpp')
-rw-r--r--src/vm/ceemain.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/vm/ceemain.cpp b/src/vm/ceemain.cpp
index ec16bdd153..a618492637 100644
--- a/src/vm/ceemain.cpp
+++ b/src/vm/ceemain.cpp
@@ -1081,8 +1081,8 @@ void EEStartupHelper(COINITIEE fFlags)
#ifdef FEATURE_MINIMETADATA_IN_TRIAGEDUMPS
// retrieve configured max size for the mini-metadata buffer (defaults to 64KB)
g_MiniMetaDataBuffMaxSize = CLRConfig::GetConfigValue(CLRConfig::INTERNAL_MiniMdBufferCapacity);
- // align up to OS_PAGE_SIZE, with a maximum of 1 MB
- g_MiniMetaDataBuffMaxSize = (DWORD) min(ALIGN_UP(g_MiniMetaDataBuffMaxSize, OS_PAGE_SIZE), 1024 * 1024);
+ // align up to GetOsPageSize(), with a maximum of 1 MB
+ g_MiniMetaDataBuffMaxSize = (DWORD) min(ALIGN_UP(g_MiniMetaDataBuffMaxSize, GetOsPageSize()), 1024 * 1024);
// allocate the buffer. this is never touched while the process is running, so it doesn't
// contribute to the process' working set. it is needed only as a "shadow" for a mini-metadata
// buffer that will be set up and reported / updated in the Watson process (the